@@ -1,6 +1,6 @@
 package PMLTQ::CGI;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::CGI::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::CGI::VERSION = '1.2.0';
 # ABSTRACT: [DEPRECATED] This is html fronted for SQLEvaluator and is currently being replaced by PMLTQ::Server
 
 use 5.006;
@@ -2390,7 +2390,7 @@ PMLTQ::CGI - [DEPRECATED] This is html fronted for SQLEvaluator and is currently
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 SYNOPSIS
 
