@@ -1,6 +1,6 @@
 package PMLTQ::Command;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Command::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Command::VERSION = '1.2.0';
 # ABSTRACT: Command base class
 
 use PMLTQ::Base -base;
@@ -167,7 +167,7 @@ PMLTQ::Command - Command base class
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 AUTHORS
 
