@@ -1,6 +1,6 @@
 package PMLTQ::Command::delete;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Command::delete::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Command::delete::VERSION = '1.2.0';
 # ABSTRACT: Deletes the treebank from database
 
 use PMLTQ::Base 'PMLTQ::Command';
@@ -31,7 +31,7 @@ PMLTQ::Command::delete - Deletes the treebank from database
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 SYNOPSIS
 
