@@ -1,6 +1,6 @@
 package PMLTQ::Command::load;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Command::load::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Command::load::VERSION = '1.2.0';
 # ABSTRACT: Load treebank to database
 
 use PMLTQ::Base 'PMLTQ::Command';
@@ -51,7 +51,7 @@ PMLTQ::Command::load - Load treebank to database
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 SYNOPSIS
 
@@ -71,7 +71,7 @@ Load treebank to database
 
 Path to configuration file. If a treebank_config is --, config is readed from STDIN.
 
-Path to ïnput directory.
+Path to input directory.
 
 =back
 
