@@ -1,6 +1,6 @@
 package PMLTQ::Command::query;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Command::query::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Command::query::VERSION = '1.2.0';
 # ABSTRACT: WIP: Executes query on treebank
 
 use PMLTQ::Base 'PMLTQ::Command';
@@ -572,7 +572,7 @@ PMLTQ::Command::query - WIP: Executes query on treebank
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 SYNOPSIS
 
