@@ -1,6 +1,6 @@
 package PMLTQ::Commands;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Commands::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Commands::VERSION = '1.2.0';
 # ABSTRACT: PMLTQ command line interface
 
 use PMLTQ::Base -strict;
@@ -166,7 +166,7 @@ PMLTQ::Commands - PMLTQ command line interface
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 SYNOPSIS
 
@@ -190,7 +190,7 @@ These commands are available by default.
 
   $ pmltq convert
 
-Uses L<PMLTQ::Command::covert> to convert data in the C<data_dir> based on
+Uses L<PMLTQ::Command::convert> to convert data in the C<data_dir> based on
 layers configuration
 
 =head2 delete
