@@ -1,6 +1,6 @@
 package PMLTQ::NG2PMLTQ;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::NG2PMLTQ::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::NG2PMLTQ::VERSION = '1.2.0';
 # ABSTRACT: [DEPRECATED] Conversion functions from NetGraph to PML-TQ
 
 
@@ -331,7 +331,7 @@ PMLTQ::NG2PMLTQ - [DEPRECATED] Conversion functions from NetGraph to PML-TQ
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 SYNOPSIS
 
