@@ -1,6 +1,6 @@
 package PMLTQ::PML2BASE;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::PML2BASE::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::PML2BASE::VERSION = '1.2.0';
 # ABSTRACT: Convert from PML to SQL
 
 
@@ -1350,7 +1350,7 @@ PMLTQ::PML2BASE - Convert from PML to SQL
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 DESCRIPTION
 
