@@ -1,6 +1,6 @@
 package PMLTQ::ParserError;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::ParserError::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::ParserError::VERSION = '1.2.0';
 # ABSTRACT: Wrapper for parsing error
 
 1; # End of PMLTQ::ParserError
@@ -17,7 +17,7 @@ PMLTQ::ParserError - Wrapper for parsing error
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 AUTHORS
 
