@@ -1,6 +1,6 @@
 package PMLTQ::Planner;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Planner::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Planner::VERSION = '1.2.0';
 # ABSTRACT: Optimalizing search trees for BtredEvaluator
 
 
@@ -290,7 +290,7 @@ PMLTQ::Planner - Optimalizing search trees for BtredEvaluator
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 DESCRIPTION
 
