@@ -1,6 +1,6 @@
 package PMLTQ::Relation::AncestorIterator;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Relation::AncestorIterator::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Relation::AncestorIterator::VERSION = '1.2.0';
 # ABSTRACT: Iterates over ancestor nodes
 
 use 5.006;
@@ -53,7 +53,7 @@ PMLTQ::Relation::AncestorIterator - Iterates over ancestor nodes
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 AUTHORS
 
