@@ -1,6 +1,6 @@
 package PMLTQ::Relation::AncestorIteratorWithBoundedDepth;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Relation::AncestorIteratorWithBoundedDepth::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Relation::AncestorIteratorWithBoundedDepth::VERSION = '1.2.0';
 # ABSTRACT: Iterates over ancestor nodes to given bound
 
 use 5.006;
@@ -87,7 +87,7 @@ PMLTQ::Relation::AncestorIteratorWithBoundedDepth - Iterates over ancestor nodes
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 AUTHORS
 
