@@ -1,6 +1,6 @@
 package PMLTQ::Relation::CurrentFilelistIterator;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Relation::CurrentFilelistIterator::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Relation::CurrentFilelistIterator::VERSION = '1.2.0';
 # ABSTRACT: Iterates over files of given file list (calling TredMacro::NextFile())
 
 use 5.006;
@@ -50,7 +50,7 @@ PMLTQ::Relation::CurrentFilelistIterator - Iterates over files of given file lis
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 AUTHORS
 
