@@ -1,6 +1,6 @@
 package PMLTQ::Relation::CurrentTreeIterator;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Relation::CurrentTreeIterator::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Relation::CurrentTreeIterator::VERSION = '1.2.0';
 # ABSTRACT: Iterates over nodes of current tree
 
 use 5.006;
@@ -53,7 +53,7 @@ PMLTQ::Relation::CurrentTreeIterator - Iterates over nodes of current tree
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 AUTHORS
 
