@@ -1,6 +1,6 @@
 package PMLTQ::Relation::Iterator;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Relation::Iterator::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Relation::Iterator::VERSION = '1.2.0';
 # ABSTRACT: Base Iterator class
 
 use 5.006;
@@ -47,7 +47,7 @@ PMLTQ::Relation::Iterator - Base Iterator class
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 AUTHORS
 
