@@ -1,6 +1,6 @@
 package PMLTQ::Relation::MemberIterator;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Relation::MemberIterator::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Relation::MemberIterator::VERSION = '1.2.0';
 # ABSTRACT: Iterates over member nodes of given list
 
 use 5.006;
@@ -47,7 +47,7 @@ PMLTQ::Relation::MemberIterator - Iterates over member nodes of given list
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 AUTHORS
 
