@@ -1,6 +1,6 @@
 package PMLTQ::Relation::OrderIterator;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Relation::OrderIterator::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Relation::OrderIterator::VERSION = '1.2.0';
 # ABSTRACT: Interates nodes based on their order
 
 use 5.006;
@@ -83,7 +83,7 @@ PMLTQ::Relation::OrderIterator - Interates nodes based on their order
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 AUTHORS
 
