@@ -1,6 +1,6 @@
 package PMLTQ::Relation::PDT;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Relation::PDT::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Relation::PDT::VERSION = '1.2.0';
 # ABSTRACT: PDT user defined relations
 
 use warnings;
@@ -223,7 +223,7 @@ PMLTQ::Relation::PDT - PDT user defined relations
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =over 5
 
