@@ -1,6 +1,6 @@
 package PMLTQ::Relation::PDT::AEChildIterator;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Relation::PDT::AEChildIterator::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Relation::PDT::AEChildIterator::VERSION = '1.2.0';
 # ABSTRACT: Effective child relation iterator on a-nodes for PDT like treebanks
 
 use strict;
@@ -38,7 +38,7 @@ PMLTQ::Relation::PDT::AEChildIterator - Effective child relation iterator on a-n
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 AUTHORS
 
