@@ -1,6 +1,6 @@
 package PMLTQ::Relation::PDT::ALexOrAuxRFIterator;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Relation::PDT::ALexOrAuxRFIterator::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Relation::PDT::ALexOrAuxRFIterator::VERSION = '1.2.0';
 # ABSTRACT: a/lex.rf or a/aux.rf relation iterator for PDT like treebanks
 
 use strict;
@@ -55,7 +55,7 @@ PMLTQ::Relation::PDT::ALexOrAuxRFIterator - a/lex.rf or a/aux.rf relation iterat
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 AUTHORS
 
