@@ -1,6 +1,6 @@
 package PMLTQ::Relation::ParentIterator;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Relation::ParentIterator::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Relation::ParentIterator::VERSION = '1.2.0';
 # ABSTRACT: Evaluates condition on the parent of start node 
 
 use 5.006;
@@ -47,7 +47,7 @@ PMLTQ::Relation::ParentIterator - Evaluates condition on the parent of start nod
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 AUTHORS
 
