@@ -1,6 +1,6 @@
 package PMLTQ::Relation::SiblingIterator;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Relation::SiblingIterator::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Relation::SiblingIterator::VERSION = '1.2.0';
 # ABSTRACT: Iterates over siblings given node
 
 use 5.006;
@@ -59,7 +59,7 @@ PMLTQ::Relation::SiblingIterator - Iterates over siblings given node
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 AUTHORS
 
