@@ -1,6 +1,6 @@
 package PMLTQ::Relation::SiblingIteratorWithDistance;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Relation::SiblingIteratorWithDistance::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Relation::SiblingIteratorWithDistance::VERSION = '1.2.0';
 # ABSTRACT: Iterates over siblings given node with boudaries
 
 use 5.006;
@@ -127,7 +127,7 @@ PMLTQ::Relation::SiblingIteratorWithDistance - Iterates over siblings given node
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 AUTHORS
 
