@@ -1,6 +1,6 @@
 package PMLTQ::Relation::SimpleListIterator;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Relation::SimpleListIterator::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Relation::SimpleListIterator::VERSION = '1.2.0';
 # ABSTRACT: Base class for all iterators that iterates on a list of nodes
 
 use 5.006;
@@ -68,7 +68,7 @@ PMLTQ::Relation::SimpleListIterator - Base class for all iterators that iterates
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 AUTHORS
 
