@@ -1,6 +1,6 @@
 package PMLTQ::Relation::TransitiveIterator;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Relation::TransitiveIterator::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Relation::TransitiveIterator::VERSION = '1.2.0';
 # ABSTRACT: Iterates over nodes that are transitive
 
 use 5.006;
@@ -139,7 +139,7 @@ PMLTQ::Relation::TransitiveIterator - Iterates over nodes that are transitive
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 AUTHORS
 
