@@ -1,6 +1,6 @@
 package PMLTQ::Relation::TreeIterator;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Relation::TreeIterator::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Relation::TreeIterator::VERSION = '1.2.0';
 # ABSTRACT: Evaluates condition on the whole tree of given node
 
 use 5.006;
@@ -70,7 +70,7 @@ PMLTQ::Relation::TreeIterator - Evaluates condition on the whole tree of given n
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 AUTHORS
 
