@@ -1,6 +1,6 @@
 package PMLTQ::Relation::Treex::AEParentCIterator;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Relation::Treex::AEParentCIterator::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Relation::Treex::AEParentCIterator::VERSION = '1.2.0';
 # ABSTRACT: Different implementation of effective parent relation iterator on a-nodes for Treex treebanks
 
 
@@ -56,7 +56,7 @@ PMLTQ::Relation::Treex::AEParentCIterator - Different implementation of effectiv
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 DESCRIPTION
 
