@@ -1,6 +1,6 @@
 package PMLTQ::Relation::Treex::AEParentIterator;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Relation::Treex::AEParentIterator::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Relation::Treex::AEParentIterator::VERSION = '1.2.0';
 # ABSTRACT: Effective parent relation iterator on a-nodes for Treex treebanks
 
 use strict;
@@ -55,7 +55,7 @@ PMLTQ::Relation::Treex::AEParentIterator - Effective parent relation iterator on
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 AUTHORS
 
