@@ -1,6 +1,6 @@
 package PMLTQ::Relation::TreexFileIterator;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::Relation::TreexFileIterator::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::Relation::TreexFileIterator::VERSION = '1.2.0';
 # ABSTRACT: Same as L<PMLTQ::Relation::FileIterator> but for Treex files
 
 use 5.006;
@@ -98,7 +98,7 @@ PMLTQ::Relation::TreexFileIterator - Same as L<PMLTQ::Relation::FileIterator> bu
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 AUTHORS
 
