@@ -1,6 +1,6 @@
 package PMLTQ::TypeMapper;
-our $AUTHORITY = 'cpan:MICHALS';
-$PMLTQ::TypeMapper::VERSION = '1.1.0';
+our $AUTHORITY = 'cpan:MATY';
+$PMLTQ::TypeMapper::VERSION = '1.2.0';
 # ABSTRACT: Helper methods for PML::Schema, relations and PML::Node types
 
 use 5.006;
@@ -276,7 +276,7 @@ PMLTQ::TypeMapper - Helper methods for PML::Schema, relations and PML::Node type
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 AUTHORS
 
